@@ -6,7 +6,7 @@ use v5.10.1;
 
 use Moo;
 
-use List::Util qw/ all min /;
+use List::Util 1.33 qw/ all min /;
 use PerlX::Maybe;
 use POSIX qw/ ceil floor /;
 use MooX::TypeTiny;
@@ -15,7 +15,7 @@ use Types::Standard qw/ is_Int Int ArrayRef /;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.0';
+our $VERSION = 'v0.2.1';
 
 
 has total_entries => (
@@ -327,7 +327,7 @@ Data::Pageset::Exponential - Page numbering for very large page numbers
 
 =head1 VERSION
 
-version v0.2.0
+version v0.2.1
 
 =head1 SYNOPSIS
 
